Properties Methods Events Direct Link

# Class Ext.ux.grid.RowEditor

Package: | Ext.ux.grid
Defined In: | ux-all-debug.js
Class: | RowEditor
Extends: | Object

Plugin (ptype = 'roweditor') that adds the ability to rapidly edit full rows in a grid. A validation mode may be enabled which uses AnchorTips to notify the user of all validation errors at once.

## Public Properties

This class has no public properties.

## Public Methods

This class has no public methods.

## Public Events

Event | Defined By
--- | ---
| afteredit : ( `Ext.ux.grid.RowEditor roweditor`, `Object changes`, `Ext.data.Record r`, `Number rowIndex` ) Fired after a row is edited and passes validation. This event is fired after the store's update event is fired with ... Fired after a row is edited and passes validation. This event is fired after the store's update event is fired with this edit. Listeners will be called with the following arguments: `roweditor` : Ext.ux.grid.RowEditor This object `changes` : Object Object with changes made to the record. `r` : Ext.data.Record The Record that was edited. `rowIndex` : Number The rowIndex of the row just edited | RowEditor
| afteredit : ( `Ext.ux.grid.RowEditor roweditor`, `Object changes`, `Ext.data.Record r`, `Number rowIndex` ) Fired after a row is edited and passes validation. This event is fired after the store's update event is fired with ... Fired after a row is edited and passes validation. This event is fired after the store's update event is fired with this edit. Listeners will be called with the following arguments: `roweditor` : Ext.ux.grid.RowEditor This object `changes` : Object Object with changes made to the record. `r` : Ext.data.Record The Record that was edited. `rowIndex` : Number The rowIndex of the row just edited | RowEditor
| beforeedit : ( `Ext.ux.grid.RowEditor roweditor`, `Number rowIndex` ) Fired before the row editor is activated. If the listener returns false the editor will not be activated. Fired before the row editor is activated. If the listener returns `false` the editor will not be activated. Listeners will be called with the following arguments: `roweditor` : Ext.ux.grid.RowEditor This object `rowIndex` : Number The rowIndex of the row just edited | RowEditor
| beforeedit : ( `Ext.ux.grid.RowEditor roweditor`, `Number rowIndex` ) Fired before the row editor is activated. If the listener returns false the editor will not be activated. Fired before the row editor is activated. If the listener returns `false` the editor will not be activated. Listeners will be called with the following arguments: `roweditor` : Ext.ux.grid.RowEditor This object `rowIndex` : Number The rowIndex of the row just edited | RowEditor
| canceledit : ( `Ext.ux.grid.RowEditor roweditor`, `Boolean forced` ) Fired when the editor is cancelled. Fired when the editor is cancelled. Listeners will be called with the following arguments: `roweditor` : Ext.ux.grid.RowEditor This object `forced` : Boolean True if the cancel button is pressed, false is the editor was invalid. | RowEditor
| canceledit : ( `Ext.ux.grid.RowEditor roweditor`, `Boolean forced` ) Fired when the editor is cancelled. Fired when the editor is cancelled. Listeners will be called with the following arguments: `roweditor` : Ext.ux.grid.RowEditor This object `forced` : Boolean True if the cancel button is pressed, false is the editor was invalid. | RowEditor
| validateedit : ( `Ext.ux.grid.RowEditor roweditor`, `Object changes`, `Ext.data.Record r`, `Number rowIndex` ) Fired after a row is edited and passes validation. If the listener returns false changes to the record will not be se... Fired after a row is edited and passes validation. If the listener returns `false` changes to the record will not be set. Listeners will be called with the following arguments: `roweditor` : Ext.ux.grid.RowEditor This object `changes` : Object Object with changes made to the record. `r` : Ext.data.Record The Record that was edited. `rowIndex` : Number The rowIndex of the row just edited | RowEditor
| validateedit : ( `Ext.ux.grid.RowEditor roweditor`, `Object changes`, `Ext.data.Record r`, `Number rowIndex` ) Fired after a row is edited and passes validation. If the listener returns false changes to the record will not be se... Fired after a row is edited and passes validation. If the listener returns `false` changes to the record will not be set. Listeners will be called with the following arguments: `roweditor` : Ext.ux.grid.RowEditor This object `changes` : Object Object with changes made to the record. `r` : Ext.data.Record The Record that was edited. `rowIndex` : Number The rowIndex of the row just edited | RowEditor